analyze.networks <-
  function(networks,...)
  {
    teamids <- data.frame(TeamID = names(networks[[1]]));

    measures <- do.call('cbind',lapply(networks,function(relation)
    {
      do.call('rbind',lapply(relation,function(team)
      {
        graph<-graph.adjacency(team);
        density <- graph.density(graph);
        clusters <- clusters(graph)$no;
        comp.ratio <- (clusters-1)/(nrow(team)-1);
        fragmentation <- distance_table(graph)$unconnected;
        all.dc<-centralization.degree(graph,mode=c('all'),loops=FALSE,normalized=TRUE);
        in.dc<-centralization.degree(graph,mode=c('in'),loops=FALSE,normalized=TRUE);
        out.dc<-centralization.degree(graph,mode=c('out'),loops=FALSE,normalized=TRUE);
        total.dc <- centralization.degree(graph,mode=c('total'),loops=FALSE,normalized=TRUE);
        bc<-centralization.betweenness(graph);
        cc<-centralization.closeness(graph);
        trans <- transitivity(graph);
        recip <- reciprocity(graph);
        data.frame(density=(density),
                   clusters=(clusters),
                   comp.ratio=comp.ratio,
                   fragmentation=fragmentation,
                   all.dc=(all.dc$centralization),
                   in.dc=(in.dc$centralization),
                   out.dc=(out.dc$centralization),
                   bc=(bc$centralization),
                   cc=(cc$centralization),
                   total.dc=(total.dc$centralization),
                   trans=trans,
                   recip=recip,
                   size=nrow(team));
      }));
    }));
    output <- cbind(teamids,measures)
    return(output)
  }
